@@ -17,15 +17,19 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Tests for the protocol client."""
 
+import StringIO
+import os
 import unittest
 import uuid
 
 from twisted.internet.defer import Deferred
+from twisted.trial.unittest import TestCase as TwistedTestCase
 
 from ubuntuone.storageprotocol import protocol_pb2, sharersp, delta, request
 from ubuntuone.storageprotocol.client import (
-    StorageClient, CreateUDF, ListVolumes, DeleteVolume, GetDelta,
-    Authenticate, MakeFile, MakeDir, PutContent, Move, Unlink)
+    StorageClient, CreateUDF, ListVolumes, DeleteVolume, GetDelta, Unlink,
+    Authenticate, MakeFile, MakeDir, PutContent, Move, BytesMessageProducer,
+)
 from ubuntuone.storageprotocol import volumes
 from tests import test_delta_info
 
@@ -168,6 +172,11 @@ class ClientTestCase(unittest.TestCase):
         """Clean up."""
         self.client = None
 
+    def test_init_maxpayloadsize(self):
+        """Get the value from the constant at init time."""
+        self.assertEqual(self.client.max_payload_size,
+                         request.MAX_PAYLOAD_SIZE)
+
     # client to server
     def test_client_get_delta(self):
         """Get a delta."""
@@ -805,5 +814,44 @@ class TestGenerationInRequestsMove(TestGenerationInRequestsPutContent):
         return Move(FakedProtocol(), None, None, None, None)
 
 
+class PutContentTestCase(TwistedTestCase):
+    """Test cases for PutContent op."""
+
+    def test_max_payload_size(self):
+        """Get the value from the protocol."""
+        self.protocol = FakedProtocol()
+        assert 12345 != self.protocol.max_payload_size
+        self.protocol.max_payload_size = 12345
+        pc = PutContent(self.protocol, None, None, None, None,
+                        None, None, None, None)
+        self.assertEqual(pc.max_payload_size, 12345)
+
+    def test_bytesmessageproducer_maxpayloadsize(self):
+        """The producer uses the payload size from the request."""
+        # set up the PutContent
+        pc = PutContent(FakedProtocol(), None, None, None, None,
+                        None, None, None, None)
+        assert 12345 != pc.max_payload_size
+        pc.max_payload_size = 12345
+
+        # set up the producer
+        fake_file = StringIO.StringIO(os.urandom(100000))
+        producer = BytesMessageProducer(pc, fake_file, 0)
+        producer.producing = True
+
+        # set up a function to check and go!
+        d = Deferred()
+
+        def check(message):
+            """Check."""
+            self.assertEqual(len(message.bytes.bytes), 12345)
+            producer.producing = False
+            d.callback(True)
+
+        pc.sendMessage = check
+        producer.go()
+        return d
+
+
 if __name__ == '__main__':
     unittest.main()
