@@ -60,6 +60,7 @@ class StorageClient(request.RequestHandler):
         self._volume_new_generation_callback = None
 
         self.line_mode = True
+        self.max_payload_size = request.MAX_PAYLOAD_SIZE
 
     def protocol_version(self):
         """Ask for the protocol version
@@ -1119,7 +1120,7 @@ class BytesMessageProducer(object):
 
         if self.offset:
             self.fh.seek(self.offset)
-        data = self.fh.read(request.MAX_PAYLOAD_SIZE)
+        data = self.fh.read(self.request.max_payload_size)
         if data:
             if self.offset:
                 self.offset += len(data)
@@ -1174,6 +1175,7 @@ class PutContent(request.Request):
         self.upload_id = upload_id
         self.new_generation = None
         self.magic_hash = magic_hash
+        self.max_payload_size = protocol.max_payload_size
 
     def _start(self):
         """Send PUT_CONTENT."""
