@@ -31,16 +31,14 @@ from twisted.internet.protocol import Protocol, connectionDone
 from twisted.internet.interfaces import IPushProducer
 from twisted.internet import defer
 # pylint and zope dont work
-# pylint: disable-msg=E0611
-# pylint: disable-msg=F0401
+# pylint: disable=E0611,F0401
 from zope.interface import implements
 
 from ubuntuone.storageprotocol import protocol_pb2, validators
 from ubuntuone.storageprotocol.errors import (
     StorageProtocolError, StorageProtocolErrorSizeTooBig,
     StorageProtocolProtocolError, StorageRequestError,
-    RequestCancelledError, error_to_exception
-)
+    RequestCancelledError, error_to_exception)
 
 
 # the max possible packet size is 2**32 (32 bits for size)
@@ -49,21 +47,22 @@ from ubuntuone.storageprotocol.errors import (
 # (two bytes overhead per packet against smaller size)
 SIZE_FMT = "!I"
 SIZE_FMT_SIZE = struct.calcsize(SIZE_FMT)
-MAX_MESSAGE_SIZE = 2**16
+MAX_MESSAGE_SIZE = 2 ** 16
 UNKNOWN_HASH = "unknown"
-# XXX: lucio.torre: wild guess on payload size, fix with something better
-MAX_PAYLOAD_SIZE = MAX_MESSAGE_SIZE-300
+# XXX lucio.torre, wild guess on payload size, fix with something better
+MAX_PAYLOAD_SIZE = MAX_MESSAGE_SIZE - 300
 
 # it's mandatory to always send the share when referring to a node in the
 # client/server operations. '' is a special share name that means that
 # the referred is the own root node, and not any of the shares
 ROOT = ''
 
+
 class RequestHandler(Protocol):
     """the base class for a network peer.
 
     @cvar REQUEST_ID_START:  the request id starting number. replace this in
-        client subclasses. servers should start at 0, clients should start at 1.
+    client subclasses. servers should start at 0, clients should start at 1.
     @cvar PROTOCOL_VERSION: the protocol version for this peer.
     """
     implements(IPushProducer)
@@ -85,13 +84,13 @@ class RequestHandler(Protocol):
     def get_new_request_id(self):
         """get a new and unused request id."""
         # register this request id
-        id = self.request_counter
+        request_id = self.request_counter
         # we increment the request counter by two;
         # clients allocate even-numbered request IDs
         # (0, 2, 4, ...) and servers allocate
         # odd-numbered request IDs (1, 3, 5, ...).
         self.request_counter += 2
-        return id
+        return request_id
 
     def connectionLost(self, reason=connectionDone):
         """Abort any outstanding requests when we lose our connection."""
@@ -161,20 +160,20 @@ class RequestHandler(Protocol):
         while len(data) > self.pending_length:
             # split and create a new message
             p = self.pending_length
-            self.buildMessage( data[:p] )
+            self.buildMessage(data[:p])
             data = data[p:]
         else:
             # just more data
-            self.pending_parts.append( data )
+            self.pending_parts.append(data)
             self.pending_length -= len(data)
 
             if self.pending_length == 0:
                 # we have a finished message
-                buffer = "".join(self.pending_parts)
+                buf = "".join(self.pending_parts)
                 self.pending_parts = []
                 if self.waiting_for == self.SIZE:
                     # send an error if size is too big, close connection
-                    sz =  struct.unpack(SIZE_FMT, buffer)[0]
+                    sz = struct.unpack(SIZE_FMT, buf)[0]
                     if sz > MAX_MESSAGE_SIZE:
                         # we cant answer this request because we cant
                         # parse it, so we just drop the connection
@@ -187,7 +186,7 @@ class RequestHandler(Protocol):
                     self.waiting_for = self.SIZE
                     self.pending_length = SIZE_FMT_SIZE
                     message = protocol_pb2.Message()
-                    message.ParseFromString(buffer)
+                    message.ParseFromString(buf)
                     self.processMessage(message)
 
     def processMessage(self, message):
@@ -204,8 +203,8 @@ class RequestHandler(Protocol):
             self.log.error("Validation error: " + ", ".join(is_invalid))
             comment = ("Validation error:\n"
                        + "\n".join(is_invalid))
-            if len(comment) > MAX_PAYLOAD_SIZE-100:
-                comment = comment[:MAX_PAYLOAD_SIZE-112] + ' [truncated]'
+            if len(comment) > MAX_PAYLOAD_SIZE - 100:
+                comment = comment[:MAX_PAYLOAD_SIZE - 112] + ' [truncated]'
             error_message = protocol_pb2.Message()
             error_message.id = message.id
             error_message.type = protocol_pb2.Message.ERROR
@@ -217,19 +216,20 @@ class RequestHandler(Protocol):
                 target = self.requests[message.id].processMessage
                 try:
                     result = target(message)
-                except Exception, e: # pylint: disable-msg=W0703
+                except Exception, e:  # pylint: disable=W0703
                     self.requests[message.id].error(e)
             else:
                 name = protocol_pb2.Message.DESCRIPTOR \
                      .enum_types_by_name['MessageType'] \
                      .values_by_number[message.type].name
 
-                handler = getattr(self, "handle_"+name, None)
+                handler = getattr(self, "handle_" + name, None)
                 if handler is not None:
                     result = handler(message)
                 else:
-                    raise Exception("peer cant handle message '%s' {%s}"%(name,
-                                    str(message).replace("\n"," ")))
+                    raise Exception("peer cant handle message '%s' {%s}" % (
+                            name,
+                            str(message).replace("\n", " ")))
         return result
 
     def sendMessage(self, message):
@@ -250,7 +250,7 @@ class RequestHandler(Protocol):
 
     def handle_NOOP(self, message):
         """handle an incoming noop message."""
-        pass # no-op
+        pass  # no-op
 
     def ping(self):
         """ ping the other end
@@ -290,7 +290,7 @@ class Request(object):
         self.protocol = protocol
         self.id = None
         # create this completion deferred
-        # XXX: lucio.torre: create timeout helpers and defaults
+        # XXX lucio.torre, create timeout helpers and defaults
         self.deferred = defer.Deferred()
         self.producer = None
         self.started = False
@@ -449,7 +449,7 @@ class RequestResponse(Request):
 
     @ivar source_message: the message the generated this request.
     """
-    # pylint: disable-msg=W0223
+    # pylint: disable=W0223
     def __init__(self, protocol, message):
         """Create a request response.
 
@@ -472,17 +472,17 @@ class Ping(Request):
     """
     def _start(self):
         """start the request sending a ping message."""
-        # pylint: disable-msg=W0201
+        # pylint: disable=W0201
         self._start_time = time.time()
         message = protocol_pb2.Message()
         message.id = self.id
         message.type = protocol_pb2.Message.PING
-        self.sendMessage( message )
+        self.sendMessage(message)
 
     def processMessage(self, message):
         """calculate rtt if message is pong, error otherwise"""
         if message.type == protocol_pb2.Message.PONG:
-            # pylint: disable-msg=W0201
+            # pylint: disable=W0201
             # attributes are created in completion
             self.rtt = time.time() - self._start_time
             self.done()
